@@ -113,7 +113,7 @@ function (formula, tau = 0.5, data, subset, weights, na.action, method = "br",
     mf <- eval.parent(mf)
     if(method == "model.frame")return(mf)
     mt <- attr(mf, "terms")
-    weights <- model.weights(mf)
+    weights <- as.vector(model.weights(mf))
     Y <- model.response(mf)
     X <- model.matrix(mt, mf, contrasts)
     eps <- .Machine$double.eps^(2/3)
@@ -1006,7 +1006,7 @@ function (object, se = NULL, covariance = FALSE, hs = TRUE, ...)
     m <- model.frame(object)
     y <- model.response(m)
     x <- model.matrix(mt, m, contrasts = object$contrasts)
-    wt <- model.weights(object$model)
+    wt <- as.vector(model.weights(object$model))
     tau <- object$tau
     eps <- .Machine$double.eps^(2/3)
     coef <- coefficients(object)
